@@ -1,37 +1,70 @@
 import os
 import shutil
-
+import json
 import urllib3
 import functools
 import platform
 import subprocess
 from log import log
-from typing import List, Optional, Set, Union
+from typing import List, Optional, Set, Union, Any, Callable
 from git import Repo,GitCommandError
 
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
-def enter_and_leave_function(func):
-    @functools.wraps(func)
-    def wrapper(*args, **kwargs):
+
+def enter_and_leave_function(func: Callable[..., Any]) -> Callable[..., Any]:
+    """
+    装饰器：记录函数调用开始、结束信息及返回结果，捕获并记录异常
+
+    功能：
+        - 函数调用前输出包含函数名和参数的日志
+        - 函数成功执行后输出包含返回值类型和内容的日志
+        - 函数执行异常时输出错误日志并重新抛出异常
+    """
+
+    @functools.wraps(func)  # 保留原函数元信息
+    def wrapper(*args: Any, **kwargs: Any) -> Any:
+        # 构建函数名
+        func_name = func.__name__
+
+        # 构建参数日志信息（优化格式和可读性）
+        param_parts = []
         if args:
-            if kwargs:
-                log.info(f"begin to run function {func.__name__},args is {args},kwargs is {kwargs}")
-            else:
-                log.info(f"begin to run function {func.__name__},args is {args}")
+            param_parts.append(f"args={args}")
+        if kwargs:
+            param_parts.append(f"kwargs={kwargs}")
+        params_str = ", ".join(param_parts)
+
+        # 函数开始日志
+        if params_str:
+            log.info(f"开始执行函数: {func_name}({params_str})")
         else:
-            if kwargs:
-                log.info(f"begin to run function {func.__name__},kwargs is {kwargs}")
-            else:
-                log.info(f"begin to run function {func.__name__}")
+            log.info(f"开始执行函数: {func_name}()")
+
         try:
+            # 执行原函数
             result = func(*args, **kwargs)
-            log_str=f"finish run function {func.__name__},result type is {type(result)}, and result is {result}"
-            log.info(log_str)
+
+            # 处理返回结果日志（限制过长结果的输出）
+            result_repr = repr(result)
+            if len(result_repr) > 500:  # 避免日志过长
+                result_repr = result_repr[:500] + "..."
+
+            log.info(
+                f"完成执行函数: {func_name}() -> "
+                f"类型: {type(result).__name__}, 结果: {result_repr}"
+            )
             return result
+
         except Exception as e:
-            log.error(f"failed to run functon {func.__name__} error message is : {e}")
-            raise e
+            # 异常日志记录（包含更多上下文信息）
+            log.error(
+                f"函数执行失败: {func_name}() -> "
+                f"异常类型: {type(e).__name__}, 消息: {str(e)}",
+                exc_info=True  # 记录完整堆栈信息，便于调试
+            )
+            raise  # 保持原有异常抛出行为
+
     return wrapper
 
 class ExecResult:
@@ -323,6 +356,49 @@ class Server():
 
         return result
 
+    @enter_and_leave_function
+    def read_json(self, file_path: str) -> Optional[Any]:
+        """
+        读取并解析JSON文件内容
+
+        参数:
+            file_path: JSON文件的路径（相对路径或绝对路径）
+
+        返回:
+            解析后的JSON数据（字典、列表等），如果发生错误则返回None
+        """
+        # 检查文件是否存在
+        if not os.path.exists(file_path):
+            log.warn(f"错误: 文件不存在 - {file_path}")
+            return None
+
+        # 检查是否为文件
+        if not os.path.isfile(file_path):
+            log.warn(f"错误: 不是有效的文件 - {file_path}")
+            return None
+
+        try:
+            # 打开并读取JSON文件
+            with open(file_path, 'r', encoding='utf-8') as file:
+                try:
+                    # 解析JSON数据
+                    json_data = json.load(file)
+                    return json_data
+                except json.JSONDecodeError as e:
+                    log.warn(f"错误: JSON解析失败 - {str(e)}，文件: {file_path}")
+                    return None
+                except Exception as e:
+                    log.warn(f"错误: 读取文件内容时发生意外 - {str(e)}，文件: {file_path}")
+                    return None
+
+        except PermissionError:
+            log.warn(f"错误: 没有权限打开文件 - {file_path}")
+            return None
+        except Exception as e:
+            log.warn(f"错误: 打开文件时发生意外 - {str(e)}，文件: {file_path}")
+            return None
+
+    @enter_and_leave_function
     def get_abs_path(self, file_name: str, dest_dir: str) -> Optional[str]:
         """
         在指定目录下查找指定文件名的文件，并返回第一个找到的文件的绝对路径
